@@ -78,7 +78,7 @@ class Scenario:
         return out
     
     def get_description(self):
-        out = "\n".join(["{} {}".format(x.prefix, x.text) for x in self.get_steps()])
+        out = "\n".join([x.get_description() for x in self.get_steps()])
         if self.is_outline():
             out += "\n\nExamples:\n"
             examples = self.get_examples()
@@ -99,4 +99,7 @@ class Step:
         self.prefix = match.group(1)
         self.text = match.group(2)
         
+    def get_description(self):
+        return "{} {}".format(self.prefix, self.text)
+        
     
\ No newline at end of file
